//global_defs.h: Global (common) definitions

#ifndef GLOBAL_DEFS_H
#define GLOBAL_DEFS_H

#define APP_HEIGHT  468
#define APP_WIDTH   800

#define LANDSCAPE_ORIENTATION   0
#define PORTRAIT_ORIENTATION    1
#define AUTO_ORIENTATION        2

#define IDX_BITRATE_96k 0
#define IDX_BITRATE_160k 1
#define IDX_BITRATE_320k 2

#define FORCE_OFFLINE_MODE_OFF 0 //force offline mode OFF (default option)
#define FORCE_OFFLINE_MODE_ON  1 //force offline mode ON

#endif // GLOBAL_DEFS_H
